<?php
/**
 * Plugin Name: Simple AJAX WooCart
 * Description: Upgrade your WooCommerce store with a customizable floating cart icon, real-time updates, AJAX, responsive design, and flexible options.
 * Version: 1.8
 * Author: Guru Plugins
 * Author URI: https://plugins.guru-is.com
 * Plugin URI: https://plugins.guru-is.com/product/simple-ajax-woocart/
 * Text Domain: simple-ajax-woocart
 * Requires at least: 4.7
 * Requires PHP: 7.4
 * Tested up to: 6.7
 * License: GPLv2 or later
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
class SimpleAJAXWooCart {
    public function __construct() {
        add_action('admin_menu', [$this, 'sa_woocart_add_settings_page']);
        add_action('admin_init', [$this, 'sa_woocart_register_settings']);
        add_action('admin_enqueue_scripts', [$this, 'sa_woocart_enqueue_admin_scripts']);
        add_action('wp_enqueue_scripts', [$this, 'sa_woocart_enqueue_scripts']);
        add_action('wp_footer', [$this, 'sa_woocart_render_cart']);
        add_action('wp_ajax_get_cart_count', [$this, 'sa_woocart_get_cart_count']);
        add_action('wp_ajax_nopriv_get_cart_count', [$this, 'sa_woocart_get_cart_count']);

		// Add session initialization for WooCommerce
		add_action('woocommerce_before_cart', [$this, 'sa_woocart_initialize_session']);
	}
    
	public function sa_woocart_initialize_session()
	{
		if (!WC()->session->has_session()) {
			WC()->session->set_customer_session_cookie(true);
		}
	}
	
	public function sa_woocart_add_settings_page()
	{
        add_submenu_page(
            'woocommerce',
            'Simple AJAX WooCart',
            'WooCart Settings',
            'manage_options',
            'simple-ajax-woocart',
            [$this, 'sa_woocart_settings_page_html']
        );
    }
	
	public function sa_woocart_register_settings()
	{
		register_setting('simple_woocart_settings', 'simple_woocart_options', [$this, 'sa_woocart_sanitize_settings']);
		add_settings_section(
		'simple_woocart_section',
		'Simple AJAX WooCart Settings',
		null,
		'simple-ajax-woocart'
		);
		add_settings_field('heading_section', '', [$this, 'sa_woocart_heading_section_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('cart_icon', 'Cart Icon', [$this, 'sa_woocart_cart_icon_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('icon_padding', 'Cart Icon Padding<br/>(in pixels)', [$this, 'sa_woocart_icon_padding_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('icon_size', 'Cart Icon Size<br/>(in pixels)', [$this, 'sa_woocart_icon_size_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('icon_shape', 'Cart Shape', [$this, 'sa_woocart_icon_shape_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('float_position', 'Floating Position', [$this, 'sa_woocart_float_position_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('margins', 'Cart Margins<br/>(in pixels)', [$this, 'sa_woocart_margins_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('icon_color', 'Color', [$this, 'sa_woocart_icon_color_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('show_item_count', 'Show Cart Quantity', [$this, 'sa_woocart_show_item_count_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('item_count_font_size', 'Quantity Font Size<br/>(in pixels}', [$this, 'sa_woocart_item_count_font_size_field'], 'simple-ajax-woocart', 'simple_woocart_section');
		add_settings_field('quantity_position', 'Quantity Position<br/>(in pixels - negative values ok)', [$this, 'sa_woocart_quantity_padding_field'], 'simple-ajax-woocart', 'simple_woocart_section');
	}
	
	public function sa_woocart_sanitize_settings($input)
	{
		$output = [];
		// Sanitize cart icon selection
		if (isset($input['cart_icon'])) {
			$output['cart_icon'] = sanitize_text_field($input['cart_icon']);
		}
		// Sanitize custom cart icon URL
		if (isset($input['custom_cart_icon']) && !empty($input['custom_cart_icon'])) {
			$output['custom_cart_icon'] = esc_url_raw($input['custom_cart_icon']);
		}
		// Sanitize icon size (default to 50 if invalid or missing)
		if (isset($input['icon_size'])) {
			$icon_size = intval($input['icon_size']);
			$output['icon_size'] = ($icon_size > 0) ? $icon_size : 50;
		}
		// Sanitize icon padding
		if (isset($input['icon_padding']) && is_array($input['icon_padding'])) {
			$output['icon_padding'] = [
				'top' => intval($input['icon_padding']['top'] ?? 5),
				'right' => intval($input['icon_padding']['right'] ?? 5),
				'bottom' => intval($input['icon_padding']['bottom'] ?? 5),
				'left' => intval($input['icon_padding']['left'] ?? 5),
			];
		}
		// Sanitize quantity
		if (isset($input['quantity_padding']) && is_array($input['quantity_padding'])) {
			$output['quantity_padding'] = [
				'top' => intval($input['quantity_padding']['top'] ?? 80),
				'left' => intval($input['quantity_padding']['left'] ?? 35),
			];
		}
		// Sanitize icon shape
		if (isset($input['icon_shape']) && in_array($input['icon_shape'], ['round', 'square'], true)) {
			$output['icon_shape'] = sanitize_text_field($input['icon_shape']);
		} else {
			$output['icon_shape'] = 'round'; // Default to round
		}
		// Sanitize icon color
		if (isset($input['icon_color'])) {
			$output['icon_color'] = sanitize_hex_color($input['icon_color']);
		}
		// Sanitize item count font size
		if (isset($input['item_count_font_size'])) {
			$font_size = intval($input['item_count_font_size']);
			$output['item_count_font_size'] = ($font_size > 0) ? $font_size : 14; // Default to 14px
		}
		// Sanitize item count background color
		if (isset($input['item_bg_color'])) {
			$output['item_bg_color'] = sanitize_hex_color($input['item_bg_color']);
		}
		// Sanitize item count text color
		if (isset($input['item_text_color'])) {
			$output['item_text_color'] = sanitize_hex_color($input['item_text_color']);
		}
		// Sanitize floating position
		if (isset($input['float_position']) && in_array($input['float_position'], ['left', 'right'], true)) {
			$output['float_position'] = sanitize_text_field($input['float_position']);
		} else {
			$output['float_position'] = 'right'; // Default to right
		}
		// Sanitize show item count
		if (isset($input['show_item_count']) && in_array($input['show_item_count'], ['yes', 'no'], true)) {
			$output['show_item_count'] = sanitize_text_field($input['show_item_count']);
		} else {
			$output['show_item_count'] = 'yes'; // Default to yes
		}
		// Sanitize margins
		if (isset($input['margins']) && is_array($input['margins'])) {
			$output['margins'] = [
				'bottom' => intval($input['margins']['bottom'] ?? 20),
				'left' => intval($input['margins']['left'] ?? 20),
				'right' => intval($input['margins']['right'] ?? 20),
			];
		}
		return $output;
	}
	
	public function sa_woocart_heading_section_field()
	{
		echo '<div><h2>Looking for advanced features like multiple cart views, cart sessions and more? <a href="https://plugins.guru-is.com/product/simple-ajax-woocart-pro/" target="_blank">GO PRO!</a></h2>';
	}
	
	public function sa_woocart_cart_icon_field()
	{
		$options = get_option('simple_woocart_options', []);
		$selected_icon = $options['cart_icon'] ?? 'icon1';
		$custom_icon = $options['custom_cart_icon'] ?? '';
		$cart_icons = [
			'icon1' => plugin_dir_url(__FILE__) . 'images/shopping-cart-1.png',
			'icon2' => plugin_dir_url(__FILE__) . 'images/shopping-cart-2.png',
			'icon3' => plugin_dir_url(__FILE__) . 'images/shopping-cart-3.png',
			'icon4' => plugin_dir_url(__FILE__) . 'images/shopping-cart-4.png',
			'icon5' => plugin_dir_url(__FILE__) . 'images/shopping-cart-5.png',
			'icon6' => plugin_dir_url(__FILE__) . 'images/shopping-cart-6.png',
		];
		echo '</div><div style="display: flex; gap: 20px; flex-wrap: wrap;">';
		// Display predefined icons
		foreach ($cart_icons as $icon_key => $icon_url) {
			echo '<div style="text-align: center;">';
			echo '<label>';
			echo '<img src="' . esc_url($icon_url) . '" alt="' . esc_attr($icon_key) . '" style="width: 50px; height: 50px; display: block; margin: 0 auto;">';
			echo '<br>';
			echo '<input type="radio" name="simple_woocart_options[cart_icon]" value="' . esc_attr($icon_key) . '" ' . checked($selected_icon, $icon_key, false) . '>';
			echo '</label>';
			echo '</div>';
		}
		// Custom icon upload section
		echo '<div style="text-align: center;">';
		echo '<label>';
		echo '<img src="' . esc_url($custom_icon ?: plugin_dir_url(__FILE__) . 'images/placeholder-icon.png') . '" alt="Custom Icon" style="width: 50px; height: 50px; display: block; margin: 0 auto;">';
		echo '<br>';
		echo '<input type="radio" name="simple_woocart_options[cart_icon]" value="custom" ' . checked($selected_icon, 'custom', false) . '>';
		echo '</label>';
		echo '<br>';
		echo '<br>';
		echo '<button type="button" class="button saw-upload-icon">Upload Custom Icon</button>';
		// Hidden input for custom icon URL
		echo '<input type="hidden" name="simple_woocart_options[custom_cart_icon]" value="' . esc_attr($custom_icon) . '" class="saw-custom-cart-icon-url">';
		echo '</div>';
		echo '</div>';
	}

	public function sa_woocart_enqueue_admin_scripts($hook) {
		// Check if we are on the correct admin page for the plugin
		if ($hook === 'woocommerce_page_simple-ajax-woocart') {
			// Enqueue WordPress media uploader
			wp_enqueue_media();

			// Enqueue WP Color Picker styles and scripts
			wp_enqueue_style('wp-color-picker');
			wp_enqueue_script(
			'simple-woocart-admin-script',
			plugin_dir_url(__FILE__) . 'assets/js/admin-script.js',
			['wp-color-picker', 'jquery'], // Dependencies
			'1.0', // Version
			true   // Load in footer
			);
		}
	}
    
    public function sa_woocart_enqueue_scripts() {
        wp_enqueue_style('simple-woocart-style', plugin_dir_url(__FILE__) . 'assets/css/style.css');
        wp_enqueue_script(
            'simple-woocart-script',
            plugin_dir_url(__FILE__) . 'assets/js/script.js', // Ensure the path is correct
            ['jquery'],
            null,
            true
        );
        wp_localize_script('simple-woocart-script', 'woocart_ajax', [
            'ajax_url' => admin_url('admin-ajax.php')
        ]);
    }
    
	public function sa_woocart_render_cart()
	{
		// Check if WooCommerce class exists
		if (!class_exists('WooCommerce')) {
			return;
		}
		// Check if the cart object is available
		if (!WC()->cart) {
			return;
		}
		// Check if the cart is empty
		if (WC()->cart->is_empty()) {
			return;
		}
		$options = get_option('simple_woocart_options', []);
		$selected_icon = $options['cart_icon'] ?? 'icon1';
		$custom_icon = $options['custom_cart_icon'] ?? '';
		// Determine the icon URL
		if ($selected_icon === 'custom' && !empty($custom_icon)) {
			$icon_url = esc_url($custom_icon); // Use custom icon URL
		} else {
			$icon_url = esc_url(plugin_dir_url(__FILE__) . 'images/' . str_replace('icon', 'shopping-cart-', $selected_icon) . '.png'); // Use static icon
		}
		$shape = $options['icon_shape'] ?? 'round';
		$size = intval($options['icon_size'] ?? 50);
		$padding = $options['icon_padding'] ?? ['top' => 5, 'right' => 5, 'bottom' => 5, 'left' => 5];
		$color = $options['icon_color'] ?? '#ffffff';
		$item_bg_color = $options['item_bg_color'] ?? '#000000';
		$item_text_color = $options['item_text_color'] ?? '#ffffff';
		$font_size = intval($options['item_count_font_size'] ?? 14);
		$position = $options['float_position'] ?? 'right';
		$show_item_count = $options['show_item_count'] ?? 'yes';
		$quantity_padding = $options['quantity_padding'] ?? ['top' => 80, 'left' => 35];
		$bottom_margin = intval($options['margins']['bottom'] ?? 20);
		$side_margin = intval($options['margins'][$position] ?? 20);
		$style = sprintf(
		'bottom: %dpx; %s: %dpx; width: %dpx; height: %dpx; background-color: %s; border-radius: %s; display: flex; justify-content: center; align-items: center; position: fixed; padding: %dpx %dpx %dpx %dpx;',
		esc_attr($bottom_margin),
		esc_attr($position),
		esc_attr($side_margin),
		esc_attr($size),
		esc_attr($size),
		esc_attr($color),
		$shape === 'round' ? '50%' : '0%',
		intval($padding['top']),
		intval($padding['right']),
		intval($padding['bottom']),
		intval($padding['left'])
		);
		// Get WooCommerce cart URL
		$cart_url = wc_get_cart_url();
		echo '<a href="' . esc_url($cart_url) . '" id="floating-woocart" style="' . esc_attr($style) . '">';
		echo '<img class="cart-icon" src="' . esc_url($icon_url) . '" alt="Cart Icon" style="width: 100%; height: 100%; object-fit: contain;">';
		if ($show_item_count === 'yes') {
			echo '<div class="saw-cart-count" style="position: absolute; background-color: ' . esc_attr($item_bg_color) . '; color: ' . esc_attr($item_text_color) . '; font-size: ' . esc_attr($font_size) . 'px; top: ' . intval($quantity_padding['top']) . 'px; left: ' . intval($quantity_padding['left']) . 'px; border-radius: 50%; width: 28px; height: 28px; display: flex; justify-content: center; align-items: center;">' . esc_attr(WC()->cart->get_cart_contents_count()) . '</div>';
		}
		echo '</a>';
	}
	
    public function sa_woocart_get_cart_count() {
        wp_send_json(['count' => WC()->cart->get_cart_contents_count()]);
    }
    
    public function sa_woocart_settings_page_html() {
        ?>
        <div class="saw-wrap">
            <form method="post" action="options.php">
                <?php
                settings_fields('simple_woocart_settings');
                do_settings_sections('simple-ajax-woocart');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }
    
	public function sa_woocart_icon_padding_field()
	{
		$options = get_option('simple_woocart_options', []);
		$padding_top = $options['icon_padding']['top'] ?? 5;
		$padding_right = $options['icon_padding']['right'] ?? 5;
		$padding_bottom = $options['icon_padding']['bottom'] ?? 5;
		$padding_left = $options['icon_padding']['left'] ?? 5;
	?>
		<div style="display: flex; gap: 20px; align-items: center;">
			<div>
				<label>Top:</label>
				<input type="number" name="simple_woocart_options[icon_padding][top]" value="<?php echo esc_attr($padding_top); ?>" style="width: 60px;" />
			</div>
			<div>
				<label>Right:</label>
				<input type="number" name="simple_woocart_options[icon_padding][right]" value="<?php echo esc_attr($padding_right); ?>" style="width: 60px;" />
			</div>
			<div>
				<label>Bottom:</label>
				<input type="number" name="simple_woocart_options[icon_padding][bottom]" value="<?php echo esc_attr($padding_bottom); ?>" style="width: 60px;" />
			</div>
			<div>
				<label>Left:</label>
				<input type="number" name="simple_woocart_options[icon_padding][left]" value="<?php echo esc_attr($padding_left); ?>" style="width: 60px;" />
			</div>
		</div>
		<?php
	}

	public function sa_woocart_icon_shape_field() {
		$options = get_option('simple_woocart_options', []);
		$shapes = ['square', 'round'];
		$selected_shape = $options['icon_shape'] ?? 'round';
	?>
		<select name="simple_woocart_options[icon_shape]">
			<?php
		foreach ($shapes as $shape) : ?>
			<option value="<?php echo esc_attr($shape); ?>" <?php selected($selected_shape, $shape); ?>>
				<?php echo esc_attr(ucfirst($shape)); ?>
			</option>
			<?php
		endforeach; ?>
		</select>
		<?php
	}

    public function sa_woocart_icon_size_field() {
        $options = get_option('simple_woocart_options', []);
        ?>
        <input type="number" name="simple_woocart_options[icon_size]" value="<?php echo esc_attr($options['icon_size'] ?? 50); ?>" />
        <?php
    }

    public function sa_woocart_icon_color_field() {
        $options = get_option('simple_woocart_options', []);
        $icon_color = $options['icon_color'] ?? '#ffffff';
        $item_bg_color = $options['item_bg_color'] ?? '#000000';
        $item_text_color = $options['item_text_color'] ?? '#ffffff';
        ?>
        <div style="display: flex; gap: 20px; align-items: center;">
            <div>
                <label>Cart Background:</label>
                <input type="text" id="simple-woocart-color-picker" name="simple_woocart_options[icon_color]" value="<?php echo esc_attr($icon_color); ?>" class="wp-color-picker" />
            </div>
            <div>
                <label>Cart Quantity Background:</label>
                <input type="text" id="simple-woocart-item-bg-color-picker" name="simple_woocart_options[item_bg_color]" value="<?php echo esc_attr($item_bg_color); ?>" class="wp-color-picker" />
            </div>
            <div>
                <label>Cart Quantity Text:</label>
                <input type="text" id="simple-woocart-item-text-color-picker" name="simple_woocart_options[item_text_color]" value="<?php echo esc_attr($item_text_color); ?>" class="wp-color-picker" />
            </div>
        </div>
<?php
    }

    public function sa_woocart_float_position_field() {
        $options = get_option('simple_woocart_options', []);
        ?>
        <select name="simple_woocart_options[float_position]">
            <option value="left" <?php selected($options['float_position'] ?? '', 'left'); ?>>Left</option>
            <option value="right" <?php selected($options['float_position'] ?? '', 'right'); ?>>Right</option>
        </select>
        <?php
    }

    public function sa_woocart_show_item_count_field() {
        $options = get_option('simple_woocart_options', []);
        ?>
        <select name="simple_woocart_options[show_item_count]">
            <option value="yes" <?php selected($options['show_item_count'] ?? '', 'yes'); ?>>Yes</option>
            <option value="no" <?php selected($options['show_item_count'] ?? '', 'no'); ?>>No</option>
        </select>
        <?php
    }

    public function sa_woocart_item_count_font_size_field() {
        $options = get_option('simple_woocart_options', []);
        $font_size = isset($options['item_count_font_size']) ? intval($options['item_count_font_size']) : 14;
        ?>
        <div style="display: flex; align-items: center; gap: 10px;">
            <input type="number" id="item_count_font_size" name="simple_woocart_options[item_count_font_size]" value="<?php echo esc_attr($font_size); ?>" style="width: 60px;" />
        </div>
        <?php
    }

	public function sa_woocart_quantity_padding_field() {
		$options = get_option('simple_woocart_options', []);
		$quantity_padding_top = $options['quantity_padding']['top'] ?? 80;
		$quantity_padding_left = $options['quantity_padding']['left'] ?? 35;
		?>
		<div style="display: flex; gap: 20px; align-items: center;">
			<div>
				<label>Top:</label>
				<input type="number" name="simple_woocart_options[quantity_padding][top]" value="<?php echo esc_attr($quantity_padding_top); ?>" style="width: 60px;" />
			</div>
			<div>
				<label>Left:</label>
				<input type="number" name="simple_woocart_options[quantity_padding][left]" value="<?php echo esc_attr($quantity_padding_left); ?>" style="width: 60px;" />
			</div>
		</div>
		<?php
	}

    public function sa_woocart_margins_field() {
        $options = get_option('simple_woocart_options', []);
        ?>
        <div style="display: flex; gap: 20px; align-items: center;">
            <div>
                <label>Bottom:</label>
                <input type="number" name="simple_woocart_options[margins][bottom]" value="<?php echo esc_attr($options['margins']['bottom'] ?? 20); ?>" style="width: 50px;" />
            </div>
            <div>
                <label>Left:</label>
                <input type="number" name="simple_woocart_options[margins][left]" value="<?php echo esc_attr($options['margins']['left'] ?? 20); ?>" style="width: 50px;" />
            </div>
            <div>
                <label>Right:</label>
                <input type="number" name="simple_woocart_options[margins][right]" value="<?php echo esc_attr($options['margins']['right'] ?? 20); ?>" style="width: 50px;" />
            </div>
        </div>
        <?php
    }
}

new SimpleAJAXWooCart();